"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def assign(hub, ctx, instance_id: str, layer_ids: List) -> None:
    r"""
    **Autogenerated function**

    Assign a registered instance to a layer.   You can assign registered on-premises instances to any layer type.   You can assign registered Amazon EC2 instances only to custom layers.   You cannot use this action with instances that were created with AWS OpsWorks Stacks.    Required Permissions: To use this action, an AWS Identity and Access Management (IAM) user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
        layer_ids(List): The layer ID, which must correspond to a custom layer. You cannot assign a registered instance to a built-in layer.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.assign(ctx, instance_id=value, layer_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.assign instance_id=value, layer_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="assign_instance",
        op_kwargs={"InstanceId": instance_id, "LayerIds": layer_ids},
    )


async def create(
    hub,
    ctx,
    stack_id: str,
    layer_ids: List,
    instance_type: str,
    auto_scaling_type: str = None,
    hostname: str = None,
    os: str = None,
    ami_id: str = None,
    ssh_key_name: str = None,
    availability_zone: str = None,
    virtualization_type: str = None,
    subnet_id: str = None,
    architecture: str = None,
    root_device_type: str = None,
    block_device_mappings: List = None,
    install_updates_on_boot: bool = None,
    ebs_optimized: bool = None,
    agent_version: str = None,
    tenancy: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an instance in a specified stack. For more information, see Adding an Instance to a Layer.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The stack ID.
        layer_ids(List): An array that contains the instance's layer IDs.
        instance_type(str): The instance type, such as t2.micro. For a list of supported instance types, open the stack in the console, choose Instances, and choose + Instance. The Size list contains the currently supported types. For more information, see Instance Families and Types. The parameter values that you use to specify the various types are in the API Name column of the Available Instance Types table.
        auto_scaling_type(str, optional): For load-based or time-based instances, the type. Windows stacks can use only time-based instances. Defaults to None.
        hostname(str, optional): The instance host name. Defaults to None.
        os(str, optional): The instance's operating system, which must be set to one of the following.   A supported Linux operating system: An Amazon Linux version, such as Amazon Linux 2018.03, Amazon Linux 2017.09, Amazon Linux 2017.03, Amazon Linux 2016.09, Amazon Linux 2016.03, Amazon Linux 2015.09, or Amazon Linux 2015.03.   A supported Ubuntu operating system, such as Ubuntu 16.04 LTS, Ubuntu 14.04 LTS, or Ubuntu 12.04 LTS.    CentOS Linux 7     Red Hat Enterprise Linux 7    A supported Windows operating system, such as Microsoft Windows Server 2012 R2 Base, Microsoft Windows Server 2012 R2 with SQL Server Express, Microsoft Windows Server 2012 R2 with SQL Server Standard, or Microsoft Windows Server 2012 R2 with SQL Server Web.   A custom AMI: Custom.   For more information about the supported operating systems, see AWS OpsWorks Stacks Operating Systems. The default option is the current Amazon Linux version. If you set this parameter to Custom, you must use the CreateInstance action's AmiId parameter to specify the custom AMI that you want to use. Block device mappings are not supported if the value is Custom. For more information about supported operating systems, see Operating SystemsFor more information about how to use custom AMIs with AWS OpsWorks Stacks, see Using Custom AMIs. Defaults to None.
        ami_id(str, optional): A custom AMI ID to be used to create the instance. The AMI should be based on one of the supported operating systems. For more information, see Using Custom AMIs.  If you specify a custom AMI, you must set Os to Custom. . Defaults to None.
        ssh_key_name(str, optional): The instance's Amazon EC2 key-pair name. Defaults to None.
        availability_zone(str, optional): The instance Availability Zone. For more information, see Regions and Endpoints. Defaults to None.
        virtualization_type(str, optional): The instance's virtualization type, paravirtual or hvm. Defaults to None.
        subnet_id(str, optional): The ID of the instance's subnet. If the stack is running in a VPC, you can use this parameter to override the stack's default subnet ID value and direct AWS OpsWorks Stacks to launch the instance in a different subnet. Defaults to None.
        architecture(str, optional): The instance architecture. The default option is x86_64. Instance types do not necessarily support both architectures. For a list of the architectures that are supported by the different instance types, see Instance Families and Types. Defaults to None.
        root_device_type(str, optional): The instance root device type. For more information, see Storage for the Root Device. Defaults to None.
        block_device_mappings(List, optional): An array of BlockDeviceMapping objects that specify the instance's block devices. For more information, see Block Device Mapping. Note that block device mappings are not supported for custom AMIs. Defaults to None.
        install_updates_on_boot(bool, optional): Whether to install operating system and package updates when the instance boots. The default value is true. To control when updates are installed, set this value to false. You must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or by manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.   We strongly recommend using the default value of true to ensure that your instances have the latest security updates. . Defaults to None.
        ebs_optimized(bool, optional): Whether to create an Amazon EBS-optimized instance. Defaults to None.
        agent_version(str, optional): The default AWS OpsWorks Stacks agent version. You have the following options:    INHERIT - Use the stack's default agent version setting.    version_number - Use the specified agent version. This value overrides the stack's default setting. To update the agent version, edit the instance configuration and specify a new version. AWS OpsWorks Stacks then automatically installs that version on the instance.   The default setting is INHERIT. To specify an agent version, you must use the complete version number, not the abbreviated number shown on the console. For a list of available agent version numbers, call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2. Defaults to None.
        tenancy(str, optional): The instance's tenancy option. The default option is no tenancy, or if the instance is running in a VPC, inherit tenancy settings from the VPC. The following are valid values for this parameter: dedicated, default, or host. Because there are costs associated with changes in tenancy options, we recommend that you research tenancy options before choosing them for your instances. For more information about dedicated hosts, see Dedicated Hosts Overview and Amazon EC2 Dedicated Hosts. For more information about dedicated instances, see Dedicated Instances and Amazon EC2 Dedicated Instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.create(
                ctx, stack_id=value, layer_ids=value, instance_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.create stack_id=value, layer_ids=value, instance_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="create_instance",
        op_kwargs={
            "StackId": stack_id,
            "LayerIds": layer_ids,
            "InstanceType": instance_type,
            "AutoScalingType": auto_scaling_type,
            "Hostname": hostname,
            "Os": os,
            "AmiId": ami_id,
            "SshKeyName": ssh_key_name,
            "AvailabilityZone": availability_zone,
            "VirtualizationType": virtualization_type,
            "SubnetId": subnet_id,
            "Architecture": architecture,
            "RootDeviceType": root_device_type,
            "BlockDeviceMappings": block_device_mappings,
            "InstallUpdatesOnBoot": install_updates_on_boot,
            "EbsOptimized": ebs_optimized,
            "AgentVersion": agent_version,
            "Tenancy": tenancy,
        },
    )


async def delete(
    hub,
    ctx,
    instance_id: str,
    delete_elastic_ip: bool = None,
    delete_volumes: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes a specified instance, which terminates the associated Amazon EC2 instance. You must stop an instance before you can delete it. For more information, see Deleting Instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
        delete_elastic_ip(bool, optional): Whether to delete the instance Elastic IP address. Defaults to None.
        delete_volumes(bool, optional): Whether to delete the instance's Amazon EBS volumes. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.delete(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.delete instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="delete_instance",
        op_kwargs={
            "InstanceId": instance_id,
            "DeleteElasticIp": delete_elastic_ip,
            "DeleteVolumes": delete_volumes,
        },
    )


async def deregister(hub, ctx, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Deregister a registered Amazon EC2 or on-premises instance. This action removes the instance from the stack and returns it to your control. This action cannot be used with instances that were created with AWS OpsWorks Stacks.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.deregister(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.deregister instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="deregister_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def describe_all(
    hub, ctx, stack_id: str = None, layer_id: str = None, instance_ids: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Requests a description of a set of instances.  This call accepts only one resource-identifying parameter.   Required Permissions: To use this action, an IAM user must have a Show, Deploy, or Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        stack_id(str, optional): A stack ID. If you use this parameter, DescribeInstances returns descriptions of the instances associated with the specified stack. Defaults to None.
        layer_id(str, optional): A layer ID. If you use this parameter, DescribeInstances returns descriptions of the instances associated with the specified layer. Defaults to None.
        instance_ids(List, optional): An array of instance IDs to be described. If you use this parameter, DescribeInstances returns a description of the specified instances. Otherwise, it returns a description of every instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="describe_instances",
        op_kwargs={
            "StackId": stack_id,
            "LayerId": layer_id,
            "InstanceIds": instance_ids,
        },
    )


async def reboot(hub, ctx, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Reboots a specified instance. For more information, see Starting, Stopping, and Rebooting Instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.reboot(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.reboot instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="reboot_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def register(
    hub,
    ctx,
    stack_id: str,
    hostname: str = None,
    public_ip: str = None,
    private_ip: str = None,
    rsa_public_key: str = None,
    rsa_public_key_fingerprint: str = None,
    instance_identity: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers instances that were created outside of AWS OpsWorks Stacks with a specified stack.  We do not recommend using this action to register instances. The complete registration operation includes two tasks: installing the AWS OpsWorks Stacks agent on the instance, and registering the instance with the stack. RegisterInstance handles only the second step. You should instead use the AWS CLI register command, which performs the entire registration operation. For more information, see  Registering an Instance with an AWS OpsWorks Stacks Stack.  Registered instances have the same requirements as instances that are created by using the CreateInstance API. For example, registered instances must be running a supported Linux-based operating system, and they must have a supported instance type. For more information about requirements for instances that you want to register, see  Preparing the Instance.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        stack_id(str): The ID of the stack that the instance is to be registered with.
        hostname(str, optional): The instance's hostname. Defaults to None.
        public_ip(str, optional): The instance's public IP address. Defaults to None.
        private_ip(str, optional): The instance's private IP address. Defaults to None.
        rsa_public_key(str, optional): The instances public RSA key. This key is used to encrypt communication between the instance and the service. Defaults to None.
        rsa_public_key_fingerprint(str, optional): The instances public RSA key fingerprint. Defaults to None.
        instance_identity(Dict, optional): An InstanceIdentity object that contains the instance's identity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.register(ctx, stack_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.register stack_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="register_instance",
        op_kwargs={
            "StackId": stack_id,
            "Hostname": hostname,
            "PublicIp": public_ip,
            "PrivateIp": private_ip,
            "RsaPublicKey": rsa_public_key,
            "RsaPublicKeyFingerprint": rsa_public_key_fingerprint,
            "InstanceIdentity": instance_identity,
        },
    )


async def start(hub, ctx, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Starts a specified instance. For more information, see Starting, Stopping, and Rebooting Instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.start(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.start instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="start_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def stop(hub, ctx, instance_id: str, force: bool = None) -> None:
    r"""
    **Autogenerated function**

    Stops a specified instance. When you stop a standard instance, the data disappears and must be reinstalled when you restart the instance. You can stop an Amazon EBS-backed instance without losing data. For more information, see Starting, Stopping, and Rebooting Instances.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
        force(bool, optional): Specifies whether to force an instance to stop. If the instance's root device type is ebs, or EBS-backed, adding the Force parameter to the StopInstances API call disassociates the AWS OpsWorks Stacks instance from EC2, and forces deletion of only the OpsWorks Stacks instance. You must also delete the formerly-associated instance in EC2 after troubleshooting and replacing the AWS OpsWorks Stacks instance with a new one. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.stop(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.stop instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="stop_instance",
        op_kwargs={"InstanceId": instance_id, "Force": force},
    )


async def unassign(hub, ctx, instance_id: str) -> None:
    r"""
    **Autogenerated function**

    Unassigns a registered instance from all layers that are using the instance. The instance remains in the stack as an unassigned instance, and can be assigned to another layer as needed. You cannot use this action with instances that were created with AWS OpsWorks Stacks.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack or an attached policy that explicitly grants permissions. For more information about user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.unassign(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.unassign instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="unassign_instance",
        op_kwargs={"InstanceId": instance_id},
    )


async def update(
    hub,
    ctx,
    instance_id: str,
    layer_ids: List = None,
    instance_type: str = None,
    auto_scaling_type: str = None,
    hostname: str = None,
    os: str = None,
    ami_id: str = None,
    ssh_key_name: str = None,
    architecture: str = None,
    install_updates_on_boot: bool = None,
    ebs_optimized: bool = None,
    agent_version: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Updates a specified instance.  Required Permissions: To use this action, an IAM user must have a Manage permissions level for the stack, or an attached policy that explicitly grants permissions. For more information on user permissions, see Managing User Permissions.

    Args:
        instance_id(str): The instance ID.
        layer_ids(List, optional): The instance's layer IDs. Defaults to None.
        instance_type(str, optional): The instance type, such as t2.micro. For a list of supported instance types, open the stack in the console, choose Instances, and choose + Instance. The Size list contains the currently supported types. For more information, see Instance Families and Types. The parameter values that you use to specify the various types are in the API Name column of the Available Instance Types table. Defaults to None.
        auto_scaling_type(str, optional): For load-based or time-based instances, the type. Windows stacks can use only time-based instances. Defaults to None.
        hostname(str, optional): The instance host name. Defaults to None.
        os(str, optional): The instance's operating system, which must be set to one of the following. You cannot update an instance that is using a custom AMI.   A supported Linux operating system: An Amazon Linux version, such as Amazon Linux 2018.03, Amazon Linux 2017.09, Amazon Linux 2017.03, Amazon Linux 2016.09, Amazon Linux 2016.03, Amazon Linux 2015.09, or Amazon Linux 2015.03.   A supported Ubuntu operating system, such as Ubuntu 16.04 LTS, Ubuntu 14.04 LTS, or Ubuntu 12.04 LTS.    CentOS Linux 7     Red Hat Enterprise Linux 7    A supported Windows operating system, such as Microsoft Windows Server 2012 R2 Base, Microsoft Windows Server 2012 R2 with SQL Server Express, Microsoft Windows Server 2012 R2 with SQL Server Standard, or Microsoft Windows Server 2012 R2 with SQL Server Web.   For more information about supported operating systems, see AWS OpsWorks Stacks Operating Systems. The default option is the current Amazon Linux version. If you set this parameter to Custom, you must use the AmiId parameter to specify the custom AMI that you want to use. For more information about supported operating systems, see Operating Systems. For more information about how to use custom AMIs with OpsWorks, see Using Custom AMIs.  You can specify a different Linux operating system for the updated stack, but you cannot change from Linux to Windows or Windows to Linux. . Defaults to None.
        ami_id(str, optional): The ID of the AMI that was used to create the instance. The value of this parameter must be the same AMI ID that the instance is already using. You cannot apply a new AMI to an instance by running UpdateInstance. UpdateInstance does not work on instances that are using custom AMIs. . Defaults to None.
        ssh_key_name(str, optional): The instance's Amazon EC2 key name. Defaults to None.
        architecture(str, optional): The instance architecture. Instance types do not necessarily support both architectures. For a list of the architectures that are supported by the different instance types, see Instance Families and Types. Defaults to None.
        install_updates_on_boot(bool, optional): Whether to install operating system and package updates when the instance boots. The default value is true. To control when updates are installed, set this value to false. You must then update your instances manually by using CreateDeployment to run the update_dependencies stack command or by manually running yum (Amazon Linux) or apt-get (Ubuntu) on the instances.   We strongly recommend using the default value of true, to ensure that your instances have the latest security updates. . Defaults to None.
        ebs_optimized(bool, optional): This property cannot be updated. Defaults to None.
        agent_version(str, optional): The default AWS OpsWorks Stacks agent version. You have the following options:    INHERIT - Use the stack's default agent version setting.    version_number - Use the specified agent version. This value overrides the stack's default setting. To update the agent version, you must edit the instance configuration and specify a new version. AWS OpsWorks Stacks then automatically installs that version on the instance.   The default setting is INHERIT. To specify an agent version, you must use the complete version number, not the abbreviated number shown on the console. For a list of available agent version numbers, call DescribeAgentVersions. AgentVersion cannot be set to Chef 12.2. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.opswork.instance.update(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.opswork.instance.update instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="opsworks",
        operation="update_instance",
        op_kwargs={
            "InstanceId": instance_id,
            "LayerIds": layer_ids,
            "InstanceType": instance_type,
            "AutoScalingType": auto_scaling_type,
            "Hostname": hostname,
            "Os": os,
            "AmiId": ami_id,
            "SshKeyName": ssh_key_name,
            "Architecture": architecture,
            "InstallUpdatesOnBoot": install_updates_on_boot,
            "EbsOptimized": ebs_optimized,
            "AgentVersion": agent_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, phone_number_id: str) -> None:
    r"""
    **Autogenerated function**

    Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime Voice Connectors before it can be deleted. Deleted phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.

    Args:
        phone_number_id(str): The phone number ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.init.delete(ctx, phone_number_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.init.delete phone_number_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_phone_number",
        op_kwargs={"PhoneNumberId": phone_number_id},
    )


async def get(hub, ctx, phone_number_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.

    Args:
        phone_number_id(str): The phone number ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.init.get(ctx, phone_number_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.init.get phone_number_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_phone_number",
        op_kwargs={"PhoneNumberId": phone_number_id},
    )


async def list_all(
    hub,
    ctx,
    status: str = None,
    product_type: str = None,
    filter_name: str = None,
    filter_value: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the phone numbers for the specified Amazon Chime account, Amazon Chime user, Amazon Chime Voice Connector, or Amazon Chime Voice Connector group.

    Args:
        status(str, optional): The phone number status. Defaults to None.
        product_type(str, optional): The phone number product type. Defaults to None.
        filter_name(str, optional): The filter to use to limit the number of results. Defaults to None.
        filter_value(str, optional): The value to use for the filter. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_phone_numbers",
        op_kwargs={
            "Status": status,
            "ProductType": product_type,
            "FilterName": filter_name,
            "FilterValue": filter_value,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def restore(hub, ctx, phone_number_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Moves a phone number from the Deletion queue back into the phone number Inventory.

    Args:
        phone_number_id(str): The phone number.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.init.restore(ctx, phone_number_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.init.restore phone_number_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="restore_phone_number",
        op_kwargs={"PhoneNumberId": phone_number_id},
    )


async def update(
    hub, ctx, phone_number_id: str, product_type: str = None, calling_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates phone number details, such as product type or calling name, for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type or the calling name in one action. For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type. Updates to outbound calling names can take 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.

    Args:
        phone_number_id(str): The phone number ID.
        product_type(str, optional): The product type. Defaults to None.
        calling_name(str, optional): The outbound calling name associated with the phone number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.phone_number.init.update(ctx, phone_number_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.phone_number.init.update phone_number_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_phone_number",
        op_kwargs={
            "PhoneNumberId": phone_number_id,
            "ProductType": product_type,
            "CallingName": calling_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def complete(
    hub, ctx, attachment_ids: List, client_token: str, connection_token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Allows you to confirm that the attachment has been uploaded using the pre-signed URL provided in StartAttachmentUpload API.

    Args:
        attachment_ids(List): A list of unique identifiers for the attachments.
        client_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
        connection_token(str): The authentication token associated with the participant's connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.attachment.upload.complete(
                ctx, attachment_ids=value, client_token=value, connection_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.attachment.upload.complete attachment_ids=value, client_token=value, connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="complete_attachment_upload",
        op_kwargs={
            "AttachmentIds": attachment_ids,
            "ClientToken": client_token,
            "ConnectionToken": connection_token,
        },
    )


async def start(
    hub,
    ctx,
    content_type: str,
    attachment_size_in_bytes: int,
    attachment_name: str,
    client_token: str,
    connection_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a pre-signed Amazon S3 URL in response for uploading the file directly to S3.

    Args:
        content_type(str): Describes the MIME file type of the attachment. For a list of supported file types, see Feature specifications in the Amazon Connect Administrator Guide.
        attachment_size_in_bytes(int): The size of the attachment in bytes.
        attachment_name(str): A case-sensitive name of the attachment being uploaded.
        client_token(str): A unique case sensitive identifier to support idempotency of request.
        connection_token(str): The authentication token associated with the participant's connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connectparticipant.attachment.upload.start(
                ctx,
                content_type=value,
                attachment_size_in_bytes=value,
                attachment_name=value,
                client_token=value,
                connection_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connectparticipant.attachment.upload.start content_type=value, attachment_size_in_bytes=value, attachment_name=value, client_token=value, connection_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connectparticipant",
        operation="start_attachment_upload",
        op_kwargs={
            "ContentType": content_type,
            "AttachmentSizeInBytes": attachment_size_in_bytes,
            "AttachmentName": attachment_name,
            "ClientToken": client_token,
            "ConnectionToken": connection_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    workload_id: str,
    lens_alias: str,
    pillar_id: str = None,
    milestone_number: int = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List lens review improvements.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        lens_alias(str): The alias of the lens, for example, serverless. Each lens is identified by its LensSummary$LensAlias.
        pillar_id(str, optional): The ID used to identify a pillar, for example, security. A pillar is identified by its PillarReviewSummary$PillarId. Defaults to None.
        milestone_number(int, optional): The milestone number. A workload can have a maximum of 100 milestones. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.lens.review.improvement.list_all(
                ctx, workload_id=value, lens_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.lens.review.improvement.list_all workload_id=value, lens_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_lens_review_improvements",
        op_kwargs={
            "WorkloadId": workload_id,
            "LensAlias": lens_alias,
            "PillarId": pillar_id,
            "MilestoneNumber": milestone_number,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    path: str,
    recursive: bool = None,
    parameter_filters: List = None,
    with_decryption: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve information about one or more parameters in a specific hierarchy.  Request results are returned on a best-effort basis. If you specify MaxResults in the request, the response includes information up to the limit specified. The number of items returned, however, can be between zero and the value of MaxResults. If the service reaches an internal limit while processing the results, it stops the operation and returns the matching values up to that point and a NextToken. You can specify the NextToken in a subsequent call to get the next set of results.

    Args:
        path(str): The hierarchy for the parameter. Hierarchies start with a forward slash (/). The hierachy is the parameter name except the last part of the parameter. For the API call to succeeed, the last part of the parameter name can't be in the path. A parameter name hierarchy can have a maximum of 15 levels. Here is an example of a hierarchy: /Finance/Prod/IAD/WinServ2016/license33  .
        recursive(bool, optional): Retrieve all parameters within a hierarchy.  If a user has access to a path, then the user can access all levels of that path. For example, if a user has permission to access path /a, then the user can also access /a/b. Even if a user has explicitly been denied access in IAM for parameter /a/b, they can still call the GetParametersByPath API operation recursively for /a and view /a/b. . Defaults to None.
        parameter_filters(List, optional): Filters to limit the request results.  For GetParametersByPath, the following filter Key names are supported: Type, KeyId, Label, and DataType. The following Key values are not supported for GetParametersByPath: tag, Name, Path, and Tier. . Defaults to None.
        with_decryption(bool, optional): Retrieve all parameters in a hierarchy with their value decrypted. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.parameter.by_path.get(ctx, path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.parameter.by_path.get path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_parameters_by_path",
        op_kwargs={
            "Path": path,
            "Recursive": recursive,
            "ParameterFilters": parameter_filters,
            "WithDecryption": with_decryption,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a link to an Amazon S3 presigned URL for the manifest file associated with the specified JobId value. You can access the manifest file for up to 60 minutes after this request has been made. To access the manifest file after 60 minutes have passed, you'll have to make another call to the GetJobManifest action. The manifest is an encrypted file that you can download after your job enters the WithCustomer status. The manifest is decrypted by using the UnlockCode code value, when you pass both values to the Snow device through the Snowball client when the client is started for the first time. As a best practice, we recommend that you don't save a copy of an UnlockCode value in the same location as the manifest file for that job. Saving these separately helps prevent unauthorized parties from gaining access to the Snow device associated with that job. The credentials of a given job, including its manifest file and unlock code, expire 360 days after the job is created.

    Args:
        job_id(str): The ID for a job that you want to get the manifest file for, for example JID123e4567-e89b-12d3-a456-426655440000.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.snowball.job.manifest.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.snowball.job.manifest.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="snowball",
        operation="get_job_manifest",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, statements: List) -> Dict:
    r"""
    **Autogenerated function**

     This operation allows you to perform batch reads and writes on data stored in DynamoDB, using PartiQL.

    Args:
        statements(List):  The list of PartiQL statements representing the batch to run. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.execute_statement.batch(ctx, statements=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.execute_statement.batch statements=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="batch_execute_statement",
        op_kwargs={"Statements": statements},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    cluster_identifier: str,
    database: str,
    db_user: str = None,
    max_results: int = None,
    next_token: str = None,
    secret_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the databases in a cluster. A token is returned to page through the database list. Depending on the authorization method, use one of the following combinations of request parameters:    Secrets Manager - specify the Amazon Resource Name (ARN) of the secret, the database name, and the cluster identifier that matches the cluster in the secret.    Temporary credentials - specify the cluster identifier, the database name, and the database user name. Permission to call the redshift:GetClusterCredentials operation is required to use this method.

    Args:
        cluster_identifier(str): The cluster identifier. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        database(str): The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        db_user(str, optional): The database user name. This parameter is required when authenticating using temporary credentials. . Defaults to None.
        max_results(int, optional): The maximum number of databases to return in the response. If more databases exist than fit in one response, then NextToken is returned to page through the results. . Defaults to None.
        next_token(str, optional): A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. . Defaults to None.
        secret_arn(str, optional): The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.database.list_all(
                ctx, cluster_identifier=value, database=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.database.list_all cluster_identifier=value, database=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="list_databases",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Database": database,
            "DbUser": db_user,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SecretArn": secret_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    network_interface_id: str,
    traffic_mirror_target_id: str,
    traffic_mirror_filter_id: str,
    session_number: int,
    packet_length: int = None,
    virtual_network_id: int = None,
    description: str = None,
    tag_specifications: List = None,
    dry_run: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Traffic Mirror session. A Traffic Mirror session actively copies packets from a Traffic Mirror source to a Traffic Mirror target. Create a filter, and then assign it to the session to define a subset of the traffic to mirror, for example all TCP traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in a different VPC connected via VPC peering or a transit gateway.  By default, no traffic is mirrored. Use CreateTrafficMirrorFilter to create filter rules that specify the traffic to mirror.

    Args:
        network_interface_id(str): The ID of the source network interface.
        traffic_mirror_target_id(str): The ID of the Traffic Mirror target.
        traffic_mirror_filter_id(str): The ID of the Traffic Mirror filter.
        packet_length(int, optional): The number of bytes in each packet to mirror. These are bytes after the VXLAN header. Do not specify this parameter when you want to mirror the entire packet. To mirror a subset of the packet, set this to the length (in bytes) that you want to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. If you do not want to mirror the entire packet, use the PacketLength parameter to specify the number of bytes in each packet to mirror. Defaults to None.
        session_number(int): The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets. Valid values are 1-32766.
        virtual_network_id(int, optional): The VXLAN ID for the Traffic Mirror session. For more information about the VXLAN protocol, see RFC 7348. If you do not specify a VirtualNetworkId, an account-wide unique id is chosen at random. Defaults to None.
        description(str, optional): The description of the Traffic Mirror session. Defaults to None.
        tag_specifications(List, optional): The tags to assign to a Traffic Mirror session. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.session.create(
                ctx,
                network_interface_id=value,
                traffic_mirror_target_id=value,
                traffic_mirror_filter_id=value,
                session_number=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.session.create network_interface_id=value, traffic_mirror_target_id=value, traffic_mirror_filter_id=value, session_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_traffic_mirror_session",
        op_kwargs={
            "NetworkInterfaceId": network_interface_id,
            "TrafficMirrorTargetId": traffic_mirror_target_id,
            "TrafficMirrorFilterId": traffic_mirror_filter_id,
            "PacketLength": packet_length,
            "SessionNumber": session_number,
            "VirtualNetworkId": virtual_network_id,
            "Description": description,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
            "ClientToken": client_token,
        },
    )


async def delete(
    hub, ctx, traffic_mirror_session_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Traffic Mirror session.

    Args:
        traffic_mirror_session_id(str): The ID of the Traffic Mirror session.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.session.delete(
                ctx, traffic_mirror_session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.session.delete traffic_mirror_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_traffic_mirror_session",
        op_kwargs={
            "TrafficMirrorSessionId": traffic_mirror_session_id,
            "DryRun": dry_run,
        },
    )


async def describe_all(
    hub,
    ctx,
    traffic_mirror_session_ids: List = None,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more Traffic Mirror sessions. By default, all Traffic Mirror sessions are described. Alternatively, you can filter the results.

    Args:
        traffic_mirror_session_ids(List, optional): The ID of the Traffic Mirror session. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    description: The Traffic Mirror session description.    network-interface-id: The ID of the Traffic Mirror session network interface.    owner-id: The ID of the account that owns the Traffic Mirror session.    packet-length: The assigned number of packets to mirror.     session-number: The assigned session number.     traffic-mirror-filter-id: The ID of the Traffic Mirror filter.    traffic-mirror-session-id: The ID of the Traffic Mirror session.    traffic-mirror-target-id: The ID of the Traffic Mirror target.    virtual-network-id: The virtual network ID of the Traffic Mirror session.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.session.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.session.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_traffic_mirror_sessions",
        op_kwargs={
            "TrafficMirrorSessionIds": traffic_mirror_session_ids,
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    traffic_mirror_session_id: str,
    traffic_mirror_target_id: str = None,
    traffic_mirror_filter_id: str = None,
    packet_length: int = None,
    session_number: int = None,
    virtual_network_id: int = None,
    description: str = None,
    remove_fields: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a Traffic Mirror session.

    Args:
        traffic_mirror_session_id(str): The ID of the Traffic Mirror session.
        traffic_mirror_target_id(str, optional): The Traffic Mirror target. The target must be in the same VPC as the source, or have a VPC peering connection with the source. Defaults to None.
        traffic_mirror_filter_id(str, optional): The ID of the Traffic Mirror filter. Defaults to None.
        packet_length(int, optional): The number of bytes in each packet to mirror. These are bytes after the VXLAN header. To mirror a subset, set this to the length (in bytes) to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. Do not specify this parameter when you want to mirror the entire packet. Defaults to None.
        session_number(int, optional): The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets. Valid values are 1-32766. Defaults to None.
        virtual_network_id(int, optional): The virtual network ID of the Traffic Mirror session. Defaults to None.
        description(str, optional): The description to assign to the Traffic Mirror session. Defaults to None.
        remove_fields(List, optional): The properties that you want to remove from the Traffic Mirror session. When you remove a property from a Traffic Mirror session, the property is set to the default. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.traffic_mirror.session.modify(
                ctx, traffic_mirror_session_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.traffic_mirror.session.modify traffic_mirror_session_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_traffic_mirror_session",
        op_kwargs={
            "TrafficMirrorSessionId": traffic_mirror_session_id,
            "TrafficMirrorTargetId": traffic_mirror_target_id,
            "TrafficMirrorFilterId": traffic_mirror_filter_id,
            "PacketLength": packet_length,
            "SessionNumber": session_number,
            "VirtualNetworkId": virtual_network_id,
            "Description": description,
            "RemoveFields": remove_fields,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags for an Batch resource. Batch resources that support tags are compute environments, jobs, job definitions, and job queues. ARNs for child jobs of array and multi-node parallel (MNP) jobs are not supported.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) that identifies the resource that tags are listed for. Batch resources that support tags are compute environments, jobs, job definitions, and job queues. ARNs for child jobs of array and multi-node parallel (MNP) jobs are not supported.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.batch.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.batch.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="batch",
        operation="list_tags_for_resource",
        op_kwargs={"resourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    listener_arn: str,
    conditions: List,
    priority: int,
    actions: List,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a rule for the specified listener. The listener must be associated with an Application Load Balancer. Each rule consists of a priority, one or more actions, and one or more conditions. Rules are evaluated in priority order, from the lowest value to the highest value. When the conditions for a rule are met, its actions are performed. If the conditions for no rules are met, the actions for the default rule are performed. For more information, see Listener rules in the Application Load Balancers Guide.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        conditions(List): The conditions.
        priority(int): The rule priority. A listener can't have multiple rules with the same priority.
        actions(List): The actions.
        tags(List, optional): The tags to assign to the rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.rule.init.create(
                ctx, listener_arn=value, conditions=value, priority=value, actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.rule.init.create listener_arn=value, conditions=value, priority=value, actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="create_rule",
        op_kwargs={
            "ListenerArn": listener_arn,
            "Conditions": conditions,
            "Priority": priority,
            "Actions": actions,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, rule_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified rule. You can't delete the default rule.

    Args:
        rule_arn(str): The Amazon Resource Name (ARN) of the rule.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.rule.init.delete(ctx, rule_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.rule.init.delete rule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="delete_rule",
        op_kwargs={"RuleArn": rule_arn},
    )


async def describe_all(
    hub,
    ctx,
    listener_arn: str = None,
    rule_arns: List = None,
    marker: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified rules or the rules for the specified listener. You must specify either a listener or one or more rules.

    Args:
        listener_arn(str, optional): The Amazon Resource Name (ARN) of the listener. Defaults to None.
        rule_arns(List, optional): The Amazon Resource Names (ARN) of the rules. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.rule.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.rule.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_rules",
        op_kwargs={
            "ListenerArn": listener_arn,
            "RuleArns": rule_arns,
            "Marker": marker,
            "PageSize": page_size,
        },
    )


async def modify(
    hub, ctx, rule_arn: str, conditions: List = None, actions: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the specified properties of the specified rule. Any properties that you do not specify are unchanged. To add an item to a list, remove an item from a list, or update an item in a list, you must provide the entire list. For example, to add an action, specify a list with the current actions plus the new action.

    Args:
        rule_arn(str): The Amazon Resource Name (ARN) of the rule.
        conditions(List, optional): The conditions. Defaults to None.
        actions(List, optional): The actions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.rule.init.modify(ctx, rule_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.rule.init.modify rule_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="modify_rule",
        op_kwargs={"RuleArn": rule_arn, "Conditions": conditions, "Actions": actions},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    cluster_name: str,
    oidc: Dict,
    tags: Dict = None,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associate an identity provider configuration to a cluster. If you want to authenticate identities using an identity provider, you can create an identity provider configuration and associate it to your cluster. After configuring authentication to your cluster you can create Kubernetes roles and clusterroles to assign permissions to the roles, and then bind the roles to the identities using Kubernetes rolebindings and clusterrolebindings. For more information see Using RBAC Authorization in the Kubernetes documentation.

    Args:
        cluster_name(str): The name of the cluster to associate the configuration to.
        oidc(Dict): An object that represents an OpenID Connect (OIDC) identity provider configuration.
        tags(Dict, optional): The metadata to apply to the configuration to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Defaults to None.
        client_request_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.identity_provider_config.associate(
                ctx, cluster_name=value, oidc=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.identity_provider_config.associate cluster_name=value, oidc=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="associate_identity_provider_config",
        op_kwargs={
            "clusterName": cluster_name,
            "oidc": oidc,
            "tags": tags,
            "clientRequestToken": client_request_token,
        },
    )


async def describe(hub, ctx, cluster_name: str, identity_provider_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns descriptive information about an identity provider configuration.

    Args:
        cluster_name(str): The cluster name that the identity provider configuration is associated to.
        identity_provider_config(Dict): An object that represents an identity provider configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.identity_provider_config.describe(
                ctx, cluster_name=value, identity_provider_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.identity_provider_config.describe cluster_name=value, identity_provider_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="describe_identity_provider_config",
        op_kwargs={
            "clusterName": cluster_name,
            "identityProviderConfig": identity_provider_config,
        },
    )


async def disassociate(
    hub,
    ctx,
    cluster_name: str,
    identity_provider_config: Dict,
    client_request_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an identity provider configuration from a cluster. If you disassociate an identity provider from your cluster, users included in the provider can no longer access the cluster. However, you can still access the cluster with Amazon Web Services IAM users.

    Args:
        cluster_name(str): The name of the cluster to disassociate an identity provider from.
        identity_provider_config(Dict): An object that represents an identity provider configuration.
        client_request_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.identity_provider_config.disassociate(
                ctx, cluster_name=value, identity_provider_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.identity_provider_config.disassociate cluster_name=value, identity_provider_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="disassociate_identity_provider_config",
        op_kwargs={
            "clusterName": cluster_name,
            "identityProviderConfig": identity_provider_config,
            "clientRequestToken": client_request_token,
        },
    )


async def list_all(
    hub, ctx, cluster_name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    A list of identity provider configurations.

    Args:
        cluster_name(str): The cluster name that you want to list identity provider configurations for.
        max_results(int, optional): The maximum number of identity provider configurations returned by ListIdentityProviderConfigs in paginated output. When you use this parameter, ListIdentityProviderConfigs returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListIdentityProviderConfigs request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListIdentityProviderConfigs returns up to 100 results and a nextToken value, if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated IdentityProviderConfigsRequest where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.identity_provider_config.list_all(ctx, cluster_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.identity_provider_config.list_all cluster_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="list_identity_provider_configs",
        op_kwargs={
            "clusterName": cluster_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update_multiple(hub, ctx, id_: str, notifications: Dict) -> Dict:
    r"""
    **Autogenerated function**

    With the UpdatePipelineNotifications operation, you can update Amazon Simple Notification Service (Amazon SNS) notifications for a pipeline. When you update notifications for a pipeline, Elastic Transcoder returns the values that you specified in the request.

    Args:
        id_(str): The identifier of the pipeline for which you want to change notification settings.
        notifications(Dict): The topic ARN for the Amazon Simple Notification Service (Amazon SNS) topic that you want to notify to report job status.  To receive notifications, you must also subscribe to the new topic in the Amazon SNS console.     Progressing: The topic ARN for the Amazon Simple Notification Service (Amazon SNS) topic that you want to notify when Elastic Transcoder has started to process jobs that are added to this pipeline. This is the ARN that Amazon SNS returned when you created the topic.    Complete: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder has finished processing a job. This is the ARN that Amazon SNS returned when you created the topic.    Warning: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters a warning condition. This is the ARN that Amazon SNS returned when you created the topic.    Error: The topic ARN for the Amazon SNS topic that you want to notify when Elastic Transcoder encounters an error condition. This is the ARN that Amazon SNS returned when you created the topic.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastictranscoder.pipeline.notification.update_multiple(
                ctx, id_=value, notifications=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastictranscoder.pipeline.notification.update_multiple id_=value, notifications=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastictranscoder",
        operation="update_pipeline_notifications",
        op_kwargs={"Id": id_, "Notifications": notifications},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def put(hub, ctx, destination_name: str, access_policy: str) -> None:
    r"""
    **Autogenerated function**

    Creates or updates an access policy associated with an existing destination. An access policy is an IAM policy document that is used to authorize claims to register a subscription filter against a given destination. If multiple AWS accounts are sending logs to this destination, each sender account must be listed separately in the policy. The policy does not support specifying * as the Principal or the use of the aws:PrincipalOrgId global key.

    Args:
        destination_name(str): A name for an existing destination.
        access_policy(str): An IAM policy document that authorizes cross-account users to deliver their log events to the associated destination. This can be up to 5120 bytes.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.destination.policy.put(
                ctx, destination_name=value, access_policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.destination.policy.put destination_name=value, access_policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_destination_policy",
        op_kwargs={"destinationName": destination_name, "accessPolicy": access_policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    namespace_id: str = None,
    creator_request_id: str = None,
    description: str = None,
    dns_config: Dict = None,
    health_check_config: Dict = None,
    health_check_custom_config: Dict = None,
    tags: List = None,
    type_: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a service. This action defines the configuration for the following entities:   For public and private DNS namespaces, one of the following combinations of DNS records in Amazon Route 53:    A     AAAA     A and AAAA     SRV     CNAME      Optionally, a health check   After you create the service, you can submit a RegisterInstance request, and Cloud Map uses the values in the configuration to create the specified entities. For the current quota on the number of instances that you can register using the same namespace and using the same service, see Cloud Map quotas in the Cloud Map Developer Guide.

    Args:
        name(str): The name that you want to assign to the service. If you want Cloud Map to create an SRV record when you register an instance and you're using a system that requires a specific SRV format, such as HAProxy, specify the following for Name:   Start the name with an underscore (_), such as _exampleservice.   End the name with ._protocol, such as ._tcp.   When you register an instance, Cloud Map creates an SRV record and assigns a name to the record by concatenating the service name and the namespace name (for example,  _exampleservice._tcp.example.com).  For services that are accessible by DNS queries, you can't create multiple services with names that differ only by case (such as EXAMPLE and example). Otherwise, these services have the same DNS name and can't be distinguished. However, if you use a namespace that's only accessible by API calls, then you can create services that with names that differ only by case. .
        namespace_id(str, optional): The ID of the namespace that you want to use to create the service. The namespace ID must be specified, but it can be specified either here or in the DnsConfig object. Defaults to None.
        creator_request_id(str, optional): A unique string that identifies the request and that allows failed CreateService requests to be retried without the risk of running the operation twice. CreatorRequestId can be any unique string (for example, a date/timestamp). Defaults to None.
        description(str, optional): A description for the service. Defaults to None.
        dns_config(Dict, optional): A complex type that contains information about the Amazon Route 53 records that you want Cloud Map to create when you register an instance. . Defaults to None.
        health_check_config(Dict, optional):  Public DNS and HTTP namespaces only. A complex type that contains settings for an optional Route 53 health check. If you specify settings for a health check, Cloud Map associates the health check with all the Route 53 DNS records that you specify in DnsConfig.  If you specify a health check configuration, you can specify either HealthCheckCustomConfig or HealthCheckConfig but not both.  For information about the charges for health checks, see Cloud Map Pricing. Defaults to None.
        health_check_custom_config(Dict, optional): A complex type that contains information about an optional custom health check.  If you specify a health check configuration, you can specify either HealthCheckCustomConfig or HealthCheckConfig but not both.  You can't add, update, or delete a HealthCheckCustomConfig configuration from an existing service. Defaults to None.
        tags(List, optional): The tags to add to the service. Each tag consists of a key and an optional value that you define. Tags keys can be up to 128 characters in length, and tag values can be up to 256 characters in length. Defaults to None.
        type_(str, optional): If present, specifies that the service instances are only discoverable using the DiscoverInstances API operation. No DNS records is registered for the service instances. The only valid value is HTTP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.service.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.service.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="create_service",
        op_kwargs={
            "Name": name,
            "NamespaceId": namespace_id,
            "CreatorRequestId": creator_request_id,
            "Description": description,
            "DnsConfig": dns_config,
            "HealthCheckConfig": health_check_config,
            "HealthCheckCustomConfig": health_check_custom_config,
            "Tags": tags,
            "Type": type_,
        },
    )


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified service. If the service still contains one or more registered instances, the request fails.

    Args:
        id_(str): The ID of the service that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.service.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.service.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="delete_service",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the settings for a specified service.

    Args:
        id_(str): The ID of the service that you want to get settings for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.service.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.service.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="get_service",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists summary information for all the services that are associated with one or more specified namespaces.

    Args:
        next_token(str, optional): For the first ListServices request, omit this value. If the response contains NextToken, submit another ListServices request to get the next group of results. Specify the value of NextToken from the previous response in the next request.  Cloud Map gets MaxResults services and then filters them based on the specified criteria. It's possible that no services in the first MaxResults services matched the specified criteria but that subsequent groups of MaxResults services do contain services that match the criteria. . Defaults to None.
        max_results(int, optional): The maximum number of services that you want Cloud Map to return in the response to a ListServices request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 services. Defaults to None.
        filters(List, optional): A complex type that contains specifications for the namespaces that you want to list services for.  If you specify more than one filter, an operation must match all filters to be returned by ListServices. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.service.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.service.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="list_services",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )


async def update(hub, ctx, id_: str, service: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Submits a request to perform the following operations:   Update the TTL setting for existing DnsRecords configurations   Add, update, or delete HealthCheckConfig for a specified service  You can't add, update, or delete a HealthCheckCustomConfig configuration.    For public and private DNS namespaces, note the following:   If you omit any existing DnsRecords or HealthCheckConfig configurations from an UpdateService request, the configurations are deleted from the service.   If you omit an existing HealthCheckCustomConfig configuration from an UpdateService request, the configuration isn't deleted from the service.   When you update settings for a service, Cloud Map also updates the corresponding settings in all the records and health checks that were created by using the specified service.

    Args:
        id_(str): The ID of the service that you want to update.
        service(Dict): A complex type that contains the new settings for the service.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.service.update(ctx, id_=value, service=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.service.update id_=value, service=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="update_service",
        op_kwargs={"Id": id_, "Service": service},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def put(
    hub,
    ctx,
    auto_scaling_group_name: str,
    scheduled_action_name: str,
    time: str = None,
    start_time: str = None,
    end_time: str = None,
    recurrence: str = None,
    min_size: int = None,
    max_size: int = None,
    desired_capacity: int = None,
    time_zone: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates or updates a scheduled scaling action for an Auto Scaling group. For more information, see Scheduled scaling in the Amazon EC2 Auto Scaling User Guide. You can view the scheduled actions for an Auto Scaling group using the DescribeScheduledActions API call. If you are no longer using a scheduled action, you can delete it by calling the DeleteScheduledAction API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        scheduled_action_name(str): The name of this scaling action.
        time(str, optional): This parameter is no longer used. Defaults to None.
        start_time(str, optional): The date and time for this action to start, in YYYY-MM-DDThh:mm:ssZ format in UTC/GMT only and in quotes (for example, "2019-06-01T00:00:00Z"). If you specify Recurrence and StartTime, Amazon EC2 Auto Scaling performs the action at this time, and then performs the action based on the specified recurrence. If you try to schedule your action in the past, Amazon EC2 Auto Scaling returns an error message. Defaults to None.
        end_time(str, optional): The date and time for the recurring schedule to end, in UTC. Defaults to None.
        recurrence(str, optional): The recurring schedule for this action. This format consists of five fields separated by white spaces: [Minute] [Hour] [Day_of_Month] [Month_of_Year] [Day_of_Week]. The value must be in quotes (for example, "30 0 1 1,6,12 *"). For more information about this format, see Crontab. When StartTime and EndTime are specified with Recurrence, they form the boundaries of when the recurring action starts and stops. Cron expressions use Universal Coordinated Time (UTC) by default. Defaults to None.
        min_size(int, optional): The minimum size of the Auto Scaling group. Defaults to None.
        max_size(int, optional): The maximum size of the Auto Scaling group. Defaults to None.
        desired_capacity(int, optional): The desired capacity is the initial capacity of the Auto Scaling group after the scheduled action runs and the capacity it attempts to maintain. It can scale beyond this capacity if you add more scaling conditions. . Defaults to None.
        time_zone(str, optional): Specifies the time zone for a cron expression. If a time zone is not provided, UTC is used by default.  Valid values are the canonical names of the IANA time zones, derived from the IANA Time Zone Database (such as Etc/GMT+9 or Pacific/Tahiti). For more information, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.scheduled.update_group_action.put(
                ctx, auto_scaling_group_name=value, scheduled_action_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.scheduled.update_group_action.put auto_scaling_group_name=value, scheduled_action_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="put_scheduled_update_group_action",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ScheduledActionName": scheduled_action_name,
            "Time": time,
            "StartTime": start_time,
            "EndTime": end_time,
            "Recurrence": recurrence,
            "MinSize": min_size,
            "MaxSize": max_size,
            "DesiredCapacity": desired_capacity,
            "TimeZone": time_zone,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def regenerate(hub, ctx, account_id: str, bot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Regenerates the security token for a bot.

    Args:
        account_id(str): The Amazon Chime account ID.
        bot_id(str): The bot ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.security_token.regenerate(
                ctx, account_id=value, bot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.security_token.regenerate account_id=value, bot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="regenerate_security_token",
        op_kwargs={"AccountId": account_id, "BotId": bot_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def resume(
    hub, ctx, instance_id: str, contact_id: str, initial_contact_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    When a contact is being recorded, and the recording has been suspended using SuspendContactRecording, this API resumes recording the call. Only voice recordings are supported at this time.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_id(str): The identifier of the contact.
        initial_contact_id(str): The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.recording.resume(
                ctx, instance_id=value, contact_id=value, initial_contact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.recording.resume instance_id=value, contact_id=value, initial_contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="resume_contact_recording",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactId": contact_id,
            "InitialContactId": initial_contact_id,
        },
    )


async def start(
    hub,
    ctx,
    instance_id: str,
    contact_id: str,
    initial_contact_id: str,
    voice_recording_configuration: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts recording the contact when the agent joins the call. StartContactRecording is a one-time action. For example, if you use StopContactRecording to stop recording an ongoing call, you can't use StartContactRecording to restart it. For scenarios where the recording has started and you want to suspend and resume it, such as when collecting sensitive information (for example, a credit card number), use SuspendContactRecording and ResumeContactRecording. You can use this API to override the recording behavior configured in the Set recording behavior block. Only voice recordings are supported at this time.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_id(str): The identifier of the contact.
        initial_contact_id(str): The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.
        voice_recording_configuration(Dict): The person being recorded.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.recording.start(
                ctx,
                instance_id=value,
                contact_id=value,
                initial_contact_id=value,
                voice_recording_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.recording.start instance_id=value, contact_id=value, initial_contact_id=value, voice_recording_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="start_contact_recording",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactId": contact_id,
            "InitialContactId": initial_contact_id,
            "VoiceRecordingConfiguration": voice_recording_configuration,
        },
    )


async def stop(
    hub, ctx, instance_id: str, contact_id: str, initial_contact_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Stops recording a call when a contact is being recorded. StopContactRecording is a one-time action. If you use StopContactRecording to stop recording an ongoing call, you can't use StartContactRecording to restart it. For scenarios where the recording has started and you want to suspend it for sensitive information (for example, to collect a credit card number), and then restart it, use SuspendContactRecording and ResumeContactRecording. Only voice recordings are supported at this time.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_id(str): The identifier of the contact.
        initial_contact_id(str): The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.recording.stop(
                ctx, instance_id=value, contact_id=value, initial_contact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.recording.stop instance_id=value, contact_id=value, initial_contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="stop_contact_recording",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactId": contact_id,
            "InitialContactId": initial_contact_id,
        },
    )


async def suspend(
    hub, ctx, instance_id: str, contact_id: str, initial_contact_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    When a contact is being recorded, this API suspends recording the call. For example, you might suspend the call recording while collecting sensitive information, such as a credit card number. Then use ResumeContactRecording to restart recording.  The period of time that the recording is suspended is filled with silence in the final recording.  Only voice recordings are supported at this time.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        contact_id(str): The identifier of the contact.
        initial_contact_id(str): The identifier of the contact. This is the identifier of the contact associated with the first interaction with the contact center.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.recording.suspend(
                ctx, instance_id=value, contact_id=value, initial_contact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.recording.suspend instance_id=value, contact_id=value, initial_contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="suspend_contact_recording",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactId": contact_id,
            "InitialContactId": initial_contact_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, account_id: str, update_user_request_items: List) -> Dict:
    r"""
    **Autogenerated function**

    Updates user details within the UpdateUserRequestItem object for up to 20 users for the specified Amazon Chime account. Currently, only LicenseType updates are supported for this action.

    Args:
        account_id(str): The Amazon Chime account ID.
        update_user_request_items(List): The request containing the user IDs and details to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.update.user.batch(
                ctx, account_id=value, update_user_request_items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.update.user.batch account_id=value, update_user_request_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_update_user",
        op_kwargs={
            "AccountId": account_id,
            "UpdateUserRequestItems": update_user_request_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    cloud_watch_logging_option: Dict,
    current_application_version_id: int = None,
    conditional_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an Amazon CloudWatch log stream to monitor application configuration errors.

    Args:
        application_name(str): The Kinesis Data Analytics application name.
        current_application_version_id(int, optional): The version ID of the Kinesis Data Analytics application. You must provide the CurrentApplicationVersionId or the ConditionalToken.You can retrieve the application version ID using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.
        cloud_watch_logging_option(Dict): Provides the Amazon CloudWatch log stream Amazon Resource Name (ARN). .
        conditional_token(str, optional): A value you use to implement strong concurrency for application updates. You must provide the CurrentApplicationVersionId or the ConditionalToken. You get the application's current ConditionalToken using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.cloud_watch_logging_option.add(
                ctx, application_name=value, cloud_watch_logging_option=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.cloud_watch_logging_option.add application_name=value, cloud_watch_logging_option=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_cloud_watch_logging_option",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "CloudWatchLoggingOption": cloud_watch_logging_option,
            "ConditionalToken": conditional_token,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    cloud_watch_logging_option_id: str,
    current_application_version_id: int = None,
    conditional_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon CloudWatch log stream from an Kinesis Data Analytics application.

    Args:
        application_name(str): The application name.
        current_application_version_id(int, optional): The version ID of the application. You must provide the CurrentApplicationVersionId or the ConditionalToken. You can retrieve the application version ID using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.
        cloud_watch_logging_option_id(str): The CloudWatchLoggingOptionId of the Amazon CloudWatch logging option to delete. You can get the CloudWatchLoggingOptionId by using the DescribeApplication operation. .
        conditional_token(str, optional): A value you use to implement strong concurrency for application updates. You must provide the CurrentApplicationVersionId or the ConditionalToken. You get the application's current ConditionalToken using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.cloud_watch_logging_option.delete(
                ctx, application_name=value, cloud_watch_logging_option_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.cloud_watch_logging_option.delete application_name=value, cloud_watch_logging_option_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_cloud_watch_logging_option",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "CloudWatchLoggingOptionId": cloud_watch_logging_option_id,
            "ConditionalToken": conditional_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the status of a ChangeToken that you got by calling GetChangeToken. ChangeTokenStatus is one of the following values:    PROVISIONED: You requested the change token by calling GetChangeToken, but you haven't used it yet in a call to create, update, or delete an AWS WAF object.    PENDING: AWS WAF is propagating the create, update, or delete request to all AWS WAF servers.    INSYNC: Propagation is complete.

    Args:
        change_token(str): The change token for which you want to get the status. This change token was previously returned in the GetChangeToken response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.change_token.status.get(ctx, change_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.change_token.status.get change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_change_token_status",
        op_kwargs={"ChangeToken": change_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, target_group_arn: str, targets: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the health of the specified targets or all of your targets.

    Args:
        target_group_arn(str): The Amazon Resource Name (ARN) of the target group.
        targets(List, optional): The targets. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.target.health.describe(ctx, target_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.target.health.describe target_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_target_health",
        op_kwargs={"TargetGroupArn": target_group_arn, "Targets": targets},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "ip_set"


async def create(hub, ctx, name: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Creates an IPSet, which you use to specify which web requests that you want to allow or block based on the IP addresses that the requests originate from. For example, if you're receiving a lot of requests from one or more individual IP addresses or one or more ranges of IP addresses and you want to block the requests, you can create an IPSet that contains those IP addresses and then configure AWS WAF to block the requests.  To create and configure an IPSet, perform the following steps:   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a CreateIPSet request.   Submit a CreateIPSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateIPSet request.   Submit an UpdateIPSet request to specify the IP addresses that you want AWS WAF to watch for.   For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        name(str): A friendly name or description of the IPSet. You can't change Name after you create the IPSet.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.ip_set_.create(ctx, name=value, change_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.ip_set.create name=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="create_ip_set",
        op_kwargs={"Name": name, "ChangeToken": change_token},
    )


async def delete(hub, ctx, ip_set_id: str, change_token: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Permanently deletes an IPSet. You can't delete an IPSet if it's still used in any Rules or if it still includes any IP addresses. If you just want to remove an IPSet from a Rule, use UpdateRule. To permanently delete an IPSet from AWS WAF, perform the following steps:   Update the IPSet to remove IP address ranges, if any. For more information, see UpdateIPSet.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of a DeleteIPSet request.   Submit a DeleteIPSet request.

    Args:
        ip_set_id(str): The IPSetId of the IPSet that you want to delete. IPSetId is returned by CreateIPSet and by ListIPSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.ip_set_.delete(
                ctx, ip_set_id=value, change_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.ip_set.delete ip_set_id=value, change_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="delete_ip_set",
        op_kwargs={"IPSetId": ip_set_id, "ChangeToken": change_token},
    )


async def get(hub, ctx, ip_set_id: str) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns the IPSet that is specified by IPSetId.

    Args:
        ip_set_id(str): The IPSetId of the IPSet that you want to get. IPSetId is returned by CreateIPSet and by ListIPSets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.ip_set_.get(ctx, ip_set_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.ip_set.get ip_set_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="get_ip_set",
        op_kwargs={"IPSetId": ip_set_id},
    )


async def list_all(hub, ctx, next_marker: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Returns an array of IPSetSummary objects in the response.

    Args:
        next_marker(str, optional): AWS WAF returns a NextMarker value in the response that allows you to list another group of IPSets. For the second and subsequent ListIPSets requests, specify the value of NextMarker from the previous response to get information about another batch of IPSets. Defaults to None.
        limit(int, optional): Specifies the number of IPSet objects that you want AWS WAF to return for this request. If you have more IPSet objects than the number you specify for Limit, the response includes a NextMarker value that you can use to get another batch of IPSet objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.ip_set_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.ip_set.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="list_ip_sets",
        op_kwargs={"NextMarker": next_marker, "Limit": limit},
    )


async def update(hub, ctx, ip_set_id: str, change_token: str, updates: List) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Inserts or deletes IPSetDescriptor objects in an IPSet. For each IPSetDescriptor object, you specify the following values:    Whether to insert or delete the object from the array. If you want to change an IPSetDescriptor object, you delete the existing object and add a new one.   The IP address version, IPv4 or IPv6.    The IP address in CIDR notation, for example, 192.0.2.0/24 (for the range of IP addresses from 192.0.2.0 to 192.0.2.255) or 192.0.2.44/32 (for the individual IP address 192.0.2.44).    AWS WAF supports IPv4 address ranges: /8 and any range between /16 through /32. AWS WAF supports IPv6 address ranges: /24, /32, /48, /56, /64, and /128. For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing. IPv6 addresses can be represented using any of the following formats:   1111:0000:0000:0000:0000:0000:0000:0111/128   1111:0:0:0:0:0:0:0111/128   1111::0111/128   1111::111/128   You use an IPSet to specify which web requests you want to allow or block based on the IP addresses that the requests originated from. For example, if you're receiving a lot of requests from one or a small number of IP addresses and you want to block the requests, you can create an IPSet that specifies those IP addresses, and then configure AWS WAF to block the requests.  To create and configure an IPSet, perform the following steps:   Submit a CreateIPSet request.   Use GetChangeToken to get the change token that you provide in the ChangeToken parameter of an UpdateIPSet request.   Submit an UpdateIPSet request to specify the IP addresses that you want AWS WAF to watch for.   When you update an IPSet, you specify the IP addresses that you want to add and/or the IP addresses that you want to delete. If you want to change an IP address, you delete the existing IP address and add the new one. You can insert a maximum of 1000 addresses in a single request. For more information about how to use the AWS WAF API to allow or block HTTP requests, see the AWS WAF Developer Guide.

    Args:
        ip_set_id(str): The IPSetId of the IPSet that you want to update. IPSetId is returned by CreateIPSet and by ListIPSets.
        change_token(str): The value returned by the most recent call to GetChangeToken.
        updates(List): An array of IPSetUpdate objects that you want to insert into or delete from an IPSet. For more information, see the applicable data types:    IPSetUpdate: Contains Action and IPSetDescriptor     IPSetDescriptor: Contains Type and Value    You can insert a maximum of 1000 addresses in a single request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf_regional.ip_set_.update(
                ctx, ip_set_id=value, change_token=value, updates=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf_regional.ip_set.update ip_set_id=value, change_token=value, updates=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf-regional",
        operation="update_ip_set",
        op_kwargs={
            "IPSetId": ip_set_id,
            "ChangeToken": change_token,
            "Updates": updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, hsm_client_certificate_identifier: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an HSM client certificate that an Amazon Redshift cluster will use to connect to the client's HSM in order to store and retrieve the keys used to encrypt the cluster databases. The command returns a public key, which you must store in the HSM. In addition to creating the HSM certificate, you must create an Amazon Redshift HSM configuration that provides a cluster the information needed to store and use encryption keys in the HSM. For more information, go to Hardware Security Modules in the Amazon Redshift Cluster Management Guide.

    Args:
        hsm_client_certificate_identifier(str): The identifier to be assigned to the new HSM client certificate that the cluster will use to connect to the HSM to use the database encryption keys.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.client_certificate.create(
                ctx, hsm_client_certificate_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.client_certificate.create hsm_client_certificate_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_hsm_client_certificate",
        op_kwargs={
            "HsmClientCertificateIdentifier": hsm_client_certificate_identifier,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, hsm_client_certificate_identifier: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified HSM client certificate.

    Args:
        hsm_client_certificate_identifier(str): The identifier of the HSM client certificate to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.client_certificate.delete(
                ctx, hsm_client_certificate_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.client_certificate.delete hsm_client_certificate_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_hsm_client_certificate",
        op_kwargs={"HsmClientCertificateIdentifier": hsm_client_certificate_identifier},
    )


async def describe_all(
    hub,
    ctx,
    hsm_client_certificate_identifier: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified HSM client certificate. If no certificate ID is specified, returns information about all the HSM certificates owned by your Amazon Web Services account. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all HSM client certificates that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all HSM client certificates that have any combination of those values are returned. If both tag keys and values are omitted from the request, HSM client certificates are returned regardless of whether they have tag keys or values associated with them.

    Args:
        hsm_client_certificate_identifier(str, optional): The identifier of a specific HSM client certificate for which you want information. If no identifier is specified, information is returned for all HSM client certificates owned by your Amazon Web Services account. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeHsmClientCertificates request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching HSM client certificates that are associated with the specified key or keys. For example, suppose that you have HSM client certificates that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the HSM client certificates that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching HSM client certificates that are associated with the specified tag value or values. For example, suppose that you have HSM client certificates that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the HSM client certificates that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.hsm.client_certificate.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.hsm.client_certificate.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_hsm_client_certificates",
        op_kwargs={
            "HsmClientCertificateIdentifier": hsm_client_certificate_identifier,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, voice_connector_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the emergency calling configuration details from the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.emergency_calling_configuration.delete(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.emergency_calling_configuration.delete voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_voice_connector_emergency_calling_configuration",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the emergency calling configuration details for the specified Amazon Chime Voice Connector.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.emergency_calling_configuration.get(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.emergency_calling_configuration.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_emergency_calling_configuration",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def put(
    hub, ctx, voice_connector_id: str, emergency_calling_configuration: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Puts emergency calling configuration details to the specified Amazon Chime Voice Connector, such as emergency phone numbers and calling countries. Origination and termination settings must be enabled for the Amazon Chime Voice Connector before emergency calling can be configured.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        emergency_calling_configuration(Dict): The emergency calling configuration details.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.emergency_calling_configuration.put(
                ctx, voice_connector_id=value, emergency_calling_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.emergency_calling_configuration.put voice_connector_id=value, emergency_calling_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_voice_connector_emergency_calling_configuration",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "EmergencyCallingConfiguration": emergency_calling_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    app_instance_arn: str,
    app_instance_user_id: str,
    name: str,
    client_request_token: str,
    metadata: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user under an Amazon Chime AppInstance. The request consists of a unique appInstanceUserId and Name for that user.

    Args:
        app_instance_arn(str): The ARN of the AppInstance request.
        app_instance_user_id(str): The user ID of the AppInstance.
        name(str): The user's name.
        metadata(str, optional): The request's metadata. Limited to a 1KB string in UTF-8. Defaults to None.
        client_request_token(str): The token assigned to the user requesting an AppInstance.
        tags(List, optional): Tags assigned to the AppInstanceUser. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.user.create(
                ctx,
                app_instance_arn=value,
                app_instance_user_id=value,
                name=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.user.create app_instance_arn=value, app_instance_user_id=value, name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_app_instance_user",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "AppInstanceUserId": app_instance_user_id,
            "Name": name,
            "Metadata": metadata,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, app_instance_user_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an AppInstanceUser.

    Args:
        app_instance_user_arn(str): The ARN of the user request being deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.user.delete(ctx, app_instance_user_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.user.delete app_instance_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_app_instance_user",
        op_kwargs={"AppInstanceUserArn": app_instance_user_arn},
    )


async def describe(hub, ctx, app_instance_user_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the full details of an AppInstanceUser .

    Args:
        app_instance_user_arn(str): The ARN of the AppInstanceUser.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.user.describe(
                ctx, app_instance_user_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.user.describe app_instance_user_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_app_instance_user",
        op_kwargs={"AppInstanceUserArn": app_instance_user_arn},
    )


async def list_all(
    hub, ctx, app_instance_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     List all AppInstanceUsers created under a single AppInstance.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
        max_results(int, optional): The maximum number of requests that you want returned. Defaults to None.
        next_token(str, optional): The token passed by previous API calls until all requested users are returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.user.list_all(ctx, app_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.user.list_all app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_app_instance_users",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, app_instance_user_arn: str, name: str, metadata: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of an AppInstanceUser. You can update names and metadata.

    Args:
        app_instance_user_arn(str): The ARN of the AppInstanceUser.
        name(str): The name of the AppInstanceUser.
        metadata(str, optional): The metadata of the AppInstanceUser. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.user.update(
                ctx, app_instance_user_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.user.update app_instance_user_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_app_instance_user",
        op_kwargs={
            "AppInstanceUserArn": app_instance_user_arn,
            "Name": name,
            "Metadata": metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the configured values for the user enrollment invitation email template.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.invitation.configuration.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.invitation.configuration.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_invitation_configuration",
        op_kwargs={},
    )


async def put(
    hub,
    ctx,
    organization_name: str,
    contact_email: str = None,
    private_skill_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Configures the email template for the user enrollment invitation with the specified attributes.

    Args:
        organization_name(str): The name of the organization sending the enrollment invite to a user.
        contact_email(str, optional): The email ID of the organization or individual contact that the enrolled user can use. . Defaults to None.
        private_skill_ids(List, optional): The list of private skill IDs that you want to recommend to the user to enable in the invitation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.invitation.configuration.put(
                ctx, organization_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.invitation.configuration.put organization_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="put_invitation_configuration",
        op_kwargs={
            "OrganizationName": organization_name,
            "ContactEmail": contact_email,
            "PrivateSkillIds": private_skill_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, service_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the account-specific endpoint for Configuration and Update Server (CUPS) protocol or LoRaWAN Network Server (LNS) connections.

    Args:
        service_type(str, optional): The service type for which to get endpoint information about. Can be CUPS for the Configuration and Update Server endpoint, or LNS for the LoRaWAN Network Server endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.service.endpoint.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.service.endpoint.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_service_endpoint",
        op_kwargs={"ServiceType": service_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def rebalance(
    hub, ctx, global_replication_group_id: str, apply_immediately: bool
) -> Dict:
    r"""
    **Autogenerated function**

    Redistribute slots to ensure uniform distribution across existing shards in the cluster.

    Args:
        global_replication_group_id(str): The name of the Global datastore.
        apply_immediately(bool): If True, redistribution is applied immediately.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.slot_in_global_replication_group.rebalance(
                ctx, global_replication_group_id=value, apply_immediately=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.slot_in_global_replication_group.rebalance global_replication_group_id=value, apply_immediately=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="rebalance_slots_in_global_replication_group",
        op_kwargs={
            "GlobalReplicationGroupId": global_replication_group_id,
            "ApplyImmediately": apply_immediately,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def admin(
    hub, ctx, user_pool_id: str, username: str, client_metadata: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Confirms user registration as an admin without using a confirmation code. Works on any user. Calling this action requires developer credentials.

    Args:
        user_pool_id(str): The user pool ID for which you want to confirm user registration.
        username(str): The user name for which you want to confirm user registration.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.  If your user pool configuration includes triggers, the AdminConfirmSignUp API action invokes the Lambda function that is specified for the post confirmation trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. In this payload, the clientMetadata attribute provides the data that you assigned to the ClientMetadata parameter in your AdminConfirmSignUp request. In your function code in Lambda, you can process the ClientMetadata value to enhance your workflow for your specific needs. For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.confirm.sign_up.admin(
                ctx, user_pool_id=value, username=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.confirm.sign_up.admin user_pool_id=value, username=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="admin_confirm_sign_up",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "Username": username,
            "ClientMetadata": client_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, operation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about any operation that returns an operation ID in the response, such as a CreateService request.  To get a list of operations that match specified criteria, see ListOperations.

    Args:
        operation_id(str): The ID of the operation that you want to get more information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.operation.get(ctx, operation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.operation.get operation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="get_operation",
        op_kwargs={"OperationId": operation_id},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists operations that match the criteria that you specify.

    Args:
        next_token(str, optional): For the first ListOperations request, omit this value. If the response contains NextToken, submit another ListOperations request to get the next group of results. Specify the value of NextToken from the previous response in the next request.  Cloud Map gets MaxResults operations and then filters them based on the specified criteria. It's possible that no operations in the first MaxResults operations matched the specified criteria but that subsequent groups of MaxResults operations do contain operations that match the criteria. . Defaults to None.
        max_results(int, optional): The maximum number of items that you want Cloud Map to return in the response to a ListOperations request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 operations. Defaults to None.
        filters(List, optional): A complex type that contains specifications for the operations that you want to list, for example, operations that you started between a specified start date and end date. If you specify more than one filter, an operation must match all filters to be returned by ListOperations. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.operation.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.operation.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="list_operations",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    load_balancer_arn: str,
    default_actions: List,
    protocol: str = None,
    port: int = None,
    ssl_policy: str = None,
    certificates: List = None,
    alpn_policy: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a listener for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. For more information, see the following:    Listeners for your Application Load Balancers     Listeners for your Network Load Balancers     Listeners for your Gateway Load Balancers    This operation is idempotent, which means that it completes at most one time. If you attempt to create multiple listeners with the same settings, each call succeeds.

    Args:
        load_balancer_arn(str): The Amazon Resource Name (ARN) of the load balancer.
        protocol(str, optional): The protocol for connections from clients to the load balancer. For Application Load Balancers, the supported protocols are HTTP and HTTPS. For Network Load Balancers, the supported protocols are TCP, TLS, UDP, and TCP_UDP. You can’t specify the UDP or TCP_UDP protocol if dual-stack mode is enabled. You cannot specify a protocol for a Gateway Load Balancer. Defaults to None.
        port(int, optional): The port on which the load balancer is listening. You cannot specify a port for a Gateway Load Balancer. Defaults to None.
        ssl_policy(str, optional): [HTTPS and TLS listeners] The security policy that defines which protocols and ciphers are supported. For more information, see Security policies in the Application Load Balancers Guide and Security policies in the Network Load Balancers Guide. Defaults to None.
        certificates(List, optional): [HTTPS and TLS listeners] The default certificate for the listener. You must provide exactly one certificate. Set CertificateArn to the certificate ARN but do not set IsDefault. Defaults to None.
        default_actions(List): The actions for the default rule.
        alpn_policy(List, optional): [TLS listeners] The name of the Application-Layer Protocol Negotiation (ALPN) policy. You can specify one policy name. The following are the possible values:    HTTP1Only     HTTP2Only     HTTP2Optional     HTTP2Preferred     None    For more information, see ALPN policies in the Network Load Balancers Guide. Defaults to None.
        tags(List, optional): The tags to assign to the listener. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.init.create(
                ctx, load_balancer_arn=value, default_actions=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.init.create load_balancer_arn=value, default_actions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="create_listener",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "Protocol": protocol,
            "Port": port,
            "SslPolicy": ssl_policy,
            "Certificates": certificates,
            "DefaultActions": default_actions,
            "AlpnPolicy": alpn_policy,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, listener_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified listener. Alternatively, your listener is deleted when you delete the load balancer to which it is attached.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.init.delete(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.init.delete listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="delete_listener",
        op_kwargs={"ListenerArn": listener_arn},
    )


async def describe_all(
    hub,
    ctx,
    load_balancer_arn: str = None,
    listener_arns: List = None,
    marker: str = None,
    page_size: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified listeners or the listeners for the specified Application Load Balancer, Network Load Balancer, or Gateway Load Balancer. You must specify either a load balancer or one or more listeners.

    Args:
        load_balancer_arn(str, optional): The Amazon Resource Name (ARN) of the load balancer. Defaults to None.
        listener_arns(List, optional): The Amazon Resource Names (ARN) of the listeners. Defaults to None.
        marker(str, optional): The marker for the next set of results. (You received this marker from a previous call.). Defaults to None.
        page_size(int, optional): The maximum number of results to return with this call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="describe_listeners",
        op_kwargs={
            "LoadBalancerArn": load_balancer_arn,
            "ListenerArns": listener_arns,
            "Marker": marker,
            "PageSize": page_size,
        },
    )


async def modify(
    hub,
    ctx,
    listener_arn: str,
    port: int = None,
    protocol: str = None,
    ssl_policy: str = None,
    certificates: List = None,
    default_actions: List = None,
    alpn_policy: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the specified properties of the specified listener. Any properties that you do not specify remain unchanged. Changing the protocol from HTTPS to HTTP, or from TLS to TCP, removes the security policy and default certificate properties. If you change the protocol from HTTP to HTTPS, or from TCP to TLS, you must add the security policy and default certificate properties. To add an item to a list, remove an item from a list, or update an item in a list, you must provide the entire list. For example, to add an action, specify a list with the current actions plus the new action.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
        port(int, optional): The port for connections from clients to the load balancer. You cannot specify a port for a Gateway Load Balancer. Defaults to None.
        protocol(str, optional): The protocol for connections from clients to the load balancer. Application Load Balancers support the HTTP and HTTPS protocols. Network Load Balancers support the TCP, TLS, UDP, and TCP_UDP protocols. You can’t change the protocol to UDP or TCP_UDP if dual-stack mode is enabled. You cannot specify a protocol for a Gateway Load Balancer. Defaults to None.
        ssl_policy(str, optional): [HTTPS and TLS listeners] The security policy that defines which protocols and ciphers are supported. For more information, see Security policies in the Application Load Balancers Guide or Security policies in the Network Load Balancers Guide. Defaults to None.
        certificates(List, optional): [HTTPS and TLS listeners] The default certificate for the listener. You must provide exactly one certificate. Set CertificateArn to the certificate ARN but do not set IsDefault. Defaults to None.
        default_actions(List, optional): The actions for the default rule. Defaults to None.
        alpn_policy(List, optional): [TLS listeners] The name of the Application-Layer Protocol Negotiation (ALPN) policy. You can specify one policy name. The following are the possible values:    HTTP1Only     HTTP2Only     HTTP2Optional     HTTP2Preferred     None    For more information, see ALPN policies in the Network Load Balancers Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elbv2.listener.init.modify(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elbv2.listener.init.modify listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elbv2",
        operation="modify_listener",
        op_kwargs={
            "ListenerArn": listener_arn,
            "Port": port,
            "Protocol": protocol,
            "SslPolicy": ssl_policy,
            "Certificates": certificates,
            "DefaultActions": default_actions,
            "AlpnPolicy": alpn_policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Chime account under the administrator's AWS account. Only Team account types are currently supported for this action. For more information about different account types, see Managing Your Amazon Chime Accounts in the Amazon Chime Administration Guide.

    Args:
        name(str): The name of the Amazon Chime account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="chime", operation="create_account", op_kwargs={"Name": name}
    )


async def delete(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Amazon Chime account. You must suspend all users before deleting Team account. You can use the BatchSuspendUser action to dodo. For EnterpriseLWA and EnterpriseAD accounts, you must release the claimed domains for your Amazon Chime account before deletion. As soon as you release the domain, all users under that account are suspended. Deleted accounts appear in your Disabled accounts list for 90 days. To restore deleted account from your Disabled accounts list, you must contact AWS Support. After 90 days, deleted accounts are permanently removed from your Disabled accounts list.

    Args:
        account_id(str): The Amazon Chime account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.init.delete(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.init.delete account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_account",
        op_kwargs={"AccountId": account_id},
    )


async def get(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified Amazon Chime account, such as account type and supported licenses.

    Args:
        account_id(str): The Amazon Chime account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.init.get(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.init.get account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_account",
        op_kwargs={"AccountId": account_id},
    )


async def list_all(
    hub,
    ctx,
    name: str = None,
    user_email: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Chime accounts under the administrator's AWS account. You can filter accounts by account name prefix. To find out which Amazon Chime account a user belongs to, you can filter by the user's email address, which returns one account result.

    Args:
        name(str, optional): Amazon Chime account name prefix with which to filter results. Defaults to None.
        user_email(str, optional): User email address with which to filter results. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_accounts",
        op_kwargs={
            "Name": name,
            "UserEmail": user_email,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, account_id: str, name: str = None, default_license: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates account details for the specified Amazon Chime account. Currently, only account name and default license updates are supported for this action.

    Args:
        account_id(str): The Amazon Chime account ID.
        name(str, optional): The new name for the specified Amazon Chime account. Defaults to None.
        default_license(str, optional): The default license applied when you add users to an Amazon Chime account. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.init.update(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.init.update account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_account",
        op_kwargs={
            "AccountId": account_id,
            "Name": name,
            "DefaultLicense": default_license,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, channels: List, profiling_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Add up to 2 anomaly notifications channels for a profiling group.

    Args:
        channels(List): One or 2 channels to report to when anomalies are detected.
        profiling_group_name(str): The name of the profiling group that we are setting up notifications for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.notification.channel.add(
                ctx, channels=value, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.notification.channel.add channels=value, profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="add_notification_channels",
        op_kwargs={"channels": channels, "profilingGroupName": profiling_group_name},
    )


async def remove(hub, ctx, channel_id: str, profiling_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Remove one anomaly notifications channel for a profiling group.

    Args:
        channel_id(str): The id of the channel that we want to stop receiving notifications.
        profiling_group_name(str): The name of the profiling group we want to change notification configuration for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.notification.channel.remove(
                ctx, channel_id=value, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.notification.channel.remove channel_id=value, profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="remove_notification_channel",
        op_kwargs={"channelId": channel_id, "profilingGroupName": profiling_group_name},
    )
